==> mingw-w64-clang-aarch64-knewstuff-qt5-5.111.0-1-any.pkg.tar.zst: clangarm64/include/KF5/KNewStuff3/KNSWidgets/knewstuffwidgets_export.h <==

#ifndef KNEWSTUFFWIDGETS_EXPORT_H
#define KNEWSTUFFWIDGETS_EXPORT_H

#ifdef KNEWSTUFFWIDGETS_STATIC_DEFINE
#  define KNEWSTUFFWIDGETS_EXPORT
#  define KNEWSTUFFWIDGETS_NO_EXPORT
#else
#  ifndef KNEWSTUFFWIDGETS_EXPORT
#    ifdef KF5NewStuffWidgets_EXPORTS
        /* We are building this library */
#      define KNEWSTUFFWIDGETS_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KNEWSTUFFWIDGETS_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KNEWSTUFFWIDGETS_NO_EXPORT
#    define KNEWSTUFFWIDGETS_NO_EXPORT 
#  endif
#endif

#ifndef KNEWSTUFFWIDGETS_DECL_DEPRECATED
#  define KNEWSTUFFWIDGETS_DECL_DEPRECATED __declspec(deprecated)
#endif

#ifndef KNEWSTUFFWIDGETS_DECL_DEPRECATED_EXPORT
#  define KNEWSTUFFWIDGETS_DECL_DEPRECATED_EXPORT KNEWSTUFFWIDGETS_EXPORT KNEWSTUFFWIDGETS_DECL_DEPRECATED
#endif

#ifndef KNEWSTUFFWIDGETS_DECL_DEPRECATED_NO_EXPORT
#  define KNEWSTUFFWIDGETS_DECL_DEPRECATED_NO_EXPORT KNEWSTUFFWIDGETS_NO_EXPORT KNEWSTUFFWIDGETS_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KNEWSTUFFWIDGETS_NO_DEPRECATED
#    define KNEWSTUFFWIDGETS_NO_DEPRECATED
#  endif
#endif

#define KNEWSTUFFWIDGETS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(KNEWSTUFFWIDGETS_NO_DEPRECATED) && !defined(KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KNEWSTUFFWIDGETS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KNEWSTUFFWIDGETS_NO_DEPRECATED_WARNINGS) && !defined(KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KNEWSTUFFWIDGETS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KNEWSTUFFWIDGETS_NO_DEPRECATED)
#  undef KNEWSTUFFWIDGETS_DEPRECATED
#  define KNEWSTUFFWIDGETS_DEPRECATED_EXPORT KNEWSTUFFWIDGETS_EXPORT
#  define KNEWSTUFFWIDGETS_DEPRECATED_NO_EXPORT KNEWSTUFFWIDGETS_NO_EXPORT
#elif defined(KNEWSTUFFWIDGETS_NO_DEPRECATED_WARNINGS)
#  define KNEWSTUFFWIDGETS_DEPRECATED
#  define KNEWSTUFFWIDGETS_DEPRECATED_EXPORT KNEWSTUFFWIDGETS_EXPORT
#  define KNEWSTUFFWIDGETS_DEPRECATED_NO_EXPORT KNEWSTUFFWIDGETS_NO_EXPORT
#else
#  define KNEWSTUFFWIDGETS_DEPRECATED KNEWSTUFFWIDGETS_DECL_DEPRECATED
#  define KNEWSTUFFWIDGETS_DEPRECATED_EXPORT KNEWSTUFFWIDGETS_DECL_DEPRECATED_EXPORT
#  define KNEWSTUFFWIDGETS_DEPRECATED_NO_EXPORT KNEWSTUFFWIDGETS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KNEWSTUFFWIDGETS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KNEWSTUFFWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KNEWSTUFFWIDGETS_NO_DEPRECATED
#  define KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56f00
#endif
#ifdef KNEWSTUFFWIDGETS_NO_DEPRECATED_WARNINGS
#  define KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE
#  ifdef KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56f00
#  endif
#endif

#ifndef KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KNEWSTUFFWIDGETS_DEPRECATED
#  define KNEWSTUFFWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KNEWSTUFFWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x55b00
#  define KNEWSTUFFWIDGETS_DEPRECATED_VERSION_5_91(text) KNEWSTUFFWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KNEWSTUFFWIDGETS_DEPRECATED_VERSION_5_91(text)
#endif
#define KNEWSTUFFWIDGETS_DEPRECATED_VERSION_5(minor, text)      KNEWSTUFFWIDGETS_DEPRECATED_VERSION_5_##minor(text)
#define KNEWSTUFFWIDGETS_DEPRECATED_VERSION(major, minor, text) KNEWSTUFFWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KNEWSTUFFWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KNEWSTUFFWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KNEWSTUFFWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KNEWSTUFFWIDGETS_DEPRECATED_VERSION(major, minor, text)
#  define KNEWSTUFFWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KNEWSTUFFWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KNEWSTUFFWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KNEWSTUFFWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KNEWSTUFFWIDGETS_EXPORT_H */

==> mingw-w64-clang-aarch64-knewstuff-qt5-5.116.0-1-any.pkg.tar.zst: clangarm64/include/KF5/KNewStuff3/KNSWidgets/knewstuffwidgets_export.h <==

#ifndef KNEWSTUFFWIDGETS_EXPORT_H
#define KNEWSTUFFWIDGETS_EXPORT_H

#ifdef KNEWSTUFFWIDGETS_STATIC_DEFINE
#  define KNEWSTUFFWIDGETS_EXPORT
#  define KNEWSTUFFWIDGETS_NO_EXPORT
#else
#  ifndef KNEWSTUFFWIDGETS_EXPORT
#    ifdef KF5NewStuffWidgets_EXPORTS
        /* We are building this library */
#      define KNEWSTUFFWIDGETS_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KNEWSTUFFWIDGETS_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KNEWSTUFFWIDGETS_NO_EXPORT
#    define KNEWSTUFFWIDGETS_NO_EXPORT 
#  endif
#endif

#ifndef KNEWSTUFFWIDGETS_DECL_DEPRECATED
#  define KNEWSTUFFWIDGETS_DECL_DEPRECATED __declspec(deprecated)
#endif

#ifndef KNEWSTUFFWIDGETS_DECL_DEPRECATED_EXPORT
#  define KNEWSTUFFWIDGETS_DECL_DEPRECATED_EXPORT KNEWSTUFFWIDGETS_EXPORT KNEWSTUFFWIDGETS_DECL_DEPRECATED
#endif

#ifndef KNEWSTUFFWIDGETS_DECL_DEPRECATED_NO_EXPORT
#  define KNEWSTUFFWIDGETS_DECL_DEPRECATED_NO_EXPORT KNEWSTUFFWIDGETS_NO_EXPORT KNEWSTUFFWIDGETS_DECL_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KNEWSTUFFWIDGETS_NO_DEPRECATED
#    define KNEWSTUFFWIDGETS_NO_DEPRECATED
#  endif
#endif

#define KNEWSTUFFWIDGETS_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))

/* Take any defaults from group settings */
#if !defined(KNEWSTUFFWIDGETS_NO_DEPRECATED) && !defined(KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  ifdef KF_NO_DEPRECATED
#    define KNEWSTUFFWIDGETS_NO_DEPRECATED
#  elif defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#    define KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#  endif
#endif
#if !defined(KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT) && defined(KF_DISABLE_DEPRECATED_BEFORE_AND_AT)
#  define KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT KF_DISABLE_DEPRECATED_BEFORE_AND_AT
#endif

#if !defined(KNEWSTUFFWIDGETS_NO_DEPRECATED_WARNINGS) && !defined(KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE)
#  ifdef KF_NO_DEPRECATED_WARNINGS
#    define KNEWSTUFFWIDGETS_NO_DEPRECATED_WARNINGS
#  elif defined(KF_DEPRECATED_WARNINGS_SINCE)
#    define KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#  endif
#endif
#if !defined(KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE) && defined(KF_DEPRECATED_WARNINGS_SINCE)
#  define KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE KF_DEPRECATED_WARNINGS_SINCE
#endif

#if defined(KNEWSTUFFWIDGETS_NO_DEPRECATED)
#  undef KNEWSTUFFWIDGETS_DEPRECATED
#  define KNEWSTUFFWIDGETS_DEPRECATED_EXPORT KNEWSTUFFWIDGETS_EXPORT
#  define KNEWSTUFFWIDGETS_DEPRECATED_NO_EXPORT KNEWSTUFFWIDGETS_NO_EXPORT
#elif defined(KNEWSTUFFWIDGETS_NO_DEPRECATED_WARNINGS)
#  define KNEWSTUFFWIDGETS_DEPRECATED
#  define KNEWSTUFFWIDGETS_DEPRECATED_EXPORT KNEWSTUFFWIDGETS_EXPORT
#  define KNEWSTUFFWIDGETS_DEPRECATED_NO_EXPORT KNEWSTUFFWIDGETS_NO_EXPORT
#else
#  define KNEWSTUFFWIDGETS_DEPRECATED KNEWSTUFFWIDGETS_DECL_DEPRECATED
#  define KNEWSTUFFWIDGETS_DEPRECATED_EXPORT KNEWSTUFFWIDGETS_DECL_DEPRECATED_EXPORT
#  define KNEWSTUFFWIDGETS_DEPRECATED_NO_EXPORT KNEWSTUFFWIDGETS_DECL_DEPRECATED_NO_EXPORT
#endif

/* No deprecated API had been removed from build */
#define KNEWSTUFFWIDGETS_EXCLUDE_DEPRECATED_BEFORE_AND_AT 0

#define KNEWSTUFFWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1

#ifdef KNEWSTUFFWIDGETS_NO_DEPRECATED
#  define KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57400
#endif
#ifdef KNEWSTUFFWIDGETS_NO_DEPRECATED_WARNINGS
#  define KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE 0
#endif

#ifndef KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE
#  ifdef KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#    define KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  else
#    define KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE 0x57400
#  endif
#endif

#ifndef KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
#  define KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0
#endif

#ifdef KNEWSTUFFWIDGETS_DEPRECATED
#  define KNEWSTUFFWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KNEWSTUFFWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT)
#else
#  define KNEWSTUFFWIDGETS_ENABLE_DEPRECATED_SINCE(major, minor) 0
#endif

#if KNEWSTUFFWIDGETS_DEPRECATED_WARNINGS_SINCE >= 0x55b00
#  define KNEWSTUFFWIDGETS_DEPRECATED_VERSION_5_91(text) KNEWSTUFFWIDGETS_DECL_DEPRECATED_TEXT(text)
#else
#  define KNEWSTUFFWIDGETS_DEPRECATED_VERSION_5_91(text)
#endif
#define KNEWSTUFFWIDGETS_DEPRECATED_VERSION_5(minor, text)      KNEWSTUFFWIDGETS_DEPRECATED_VERSION_5_##minor(text)
#define KNEWSTUFFWIDGETS_DEPRECATED_VERSION(major, minor, text) KNEWSTUFFWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
#define KNEWSTUFFWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KNEWSTUFFWIDGETS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
#  define KNEWSTUFFWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KNEWSTUFFWIDGETS_DEPRECATED_VERSION(major, minor, text)
#  define KNEWSTUFFWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KNEWSTUFFWIDGETS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#else
#  define KNEWSTUFFWIDGETS_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
#  define KNEWSTUFFWIDGETS_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
#endif

#endif /* KNEWSTUFFWIDGETS_EXPORT_H */
